<?php

// use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\AgentController;
use App\Http\Controllers\RegisterController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\CmsController;
use Illuminate\Support\Facades\DB;
use App\Http\Helper;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Route::get('/', function () {
//     return view('welcome');
// });

// Auth::routes();

Route::prefix('admin')->name('admin.')->group(function () {

    Route::get('/',[AdminController::class,'AdminLogin']);
    
    Route::middleware(['guest:AdminLogin'])->group(function () {
        Route::get('/login',[AdminController::class,'AdminLogin'])->name('login');
        Route::post('/dologin',[AdminController::class,'AdminLogedIn'])->name('dologin');
    });

    Route::middleware(['auth:AdminLogin'])->group(function () {
        Route::get('/orders',[AdminController::class,'orders'])->name('orders');
        Route::get('/orders/view/{orderId}',[AdminController::class,'viewProduct'])->name('viewProduct');
        Route::post('/orders/view/{orderId}',[AdminController::class,'saveProduct'])->name('saveProduct');
        Route::get('/ProductByAgent',[AdminController::class,'ProductByAgent']);
        Route::get('/GetPriceByProduct',[AdminController::class,'GetPriceByProduct']);
        Route::get('/GetDeliveryType',[AdminController::class,'GetDeliveryType']);
        Route::get('/getOrderID',[AdminController::class,'getOrderID']);
        Route::post('/ReAssignProduct',[AdminController::class,'ReAssignProduct']);
        Route::get('/getReAssignPrice',[AdminController::class,'getReAssignPrice']);
        Route::get('/Reassign',[AdminController::class,'Reassign']);
        Route::get('/mailStatus',[AdminController::class,'mailStatus']);

        Route::get('/main', [AdminController::class, 'main'])->name('main');
        Route::post('/productAssign', [AdminController::class, 'search'])->name('search');
        Route::get('/dashboard/{id}/{agentId}',[AdminController::class,'orderDetails'])->name('orderDetails');
        Route::post('/dashboard/{id}/{agentId}',[AdminController::class,'UpdateProductStatus'])->name('UpdateProductStatus');

        Route::get('/report', [AdminController::class, 'report'])->name('report');
        Route::post('/report', [AdminController::class, 'reportTable'])->name('reportTable');

        Route::get('/ProfitReport', [AdminController::class, 'ProfitReport'])->name('ProfitReport');
        Route::post('/ProfitReport', [AdminController::class, 'ProfitReportSearch'])->name('ProfitReportSearch');

        Route::get('/getAgentId',[AdminController::class,'getAgentId']);

        Route::any('/product', [ProductController::class, 'product'])->name('product');
        Route::any('/product-add', [ProductController::class, 'productAdd'])->name('product-add');
        Route::any('/product-edit/{id}', [ProductController::class, 'productEdit'])->name('product-edit');
        Route::any('/bulkproductedit', [ProductController::class, 'bulkproductedit'])->name('bulkproductedit');
        Route::any('/bulkproductupload', [ProductController::class, 'bulkproductupload'])->name('bulkproductupload');
        Route::any('/upgrade_sort_order', [ProductController::class, 'upgrade_sort_order'])->name('upgrade_sort_order');
        Route::any('/product_categorywise_sortorder', [ProductController::class, 'product_categorywise_sortorder'])->name('product_categorywise_sortorder');
        Route::any('/product_sortorder_update', [ProductController::class, 'product_sortorder_update'])->name('product_sortorder_update');
        Route::any('/dbfldupdate', [ProductController::class, 'dbfldupdate'])->name('dbfldupdate');
        Route::get('/productexceldownload', [ProductController::class, 'productexceldownload'])->name('productexceldownload');
        Route::post('/getcategory', [ProductController::class, 'getcategory'])->name('getcategory');
        Route::get('/status/{id}', [ProductController::class, 'status'])->name('status');
        Route::any('/status-update', [ProductController::class, 'statusUpdate'])->name('status-update');

        Route::group(['prefix' => 'category', 'as' => 'category.'], function () {
            Route::any('/', [CategoryController::class, 'list'])->name('list');
            Route::post('/status', [CategoryController::class, 'status'])->name('status');
            Route::any('/add', [CategoryController::class, 'add'])->name('add');
            Route::any('/edit/{id}', [CategoryController::class, 'edit'])->name('edit');
            Route::get('/delete/{id}', [CategoryController::class, 'delete'])->name('delete');
            Route::get('/list_banners/{id}', [CategoryController::class, 'list_banners'])->name('list_banners');
            Route::any('/list_banners_edit/{id}', [CategoryController::class, 'list_banners_edit'])->name('list_banners_edit');
            Route::any('/list_banners_add/{id}', [CategoryController::class, 'list_banners_add'])->name('list_banners_add');
            Route::post('/catbanstatus', [CategoryController::class, 'catbanstatus'])->name('catbanstatus');
        });

        Route::group(['prefix' => 'cms', 'as' => 'cms.'], function() {
            Route::any('/', [CmsController::class, 'list'])->name('list');
            Route::any('/add', [CmsController::class, 'add'])->name('add');
            Route::any('/edit/{id}', [CmsController::class, 'edit'])->name('edit');
            Route::get('/list_cms/{id}', [CmsController::class, 'list_cms'])->name('list_cms');
        });



        Route::get('/logout', [AdminController::class, 'logout'])->name('logout');
    });
});

Route::prefix('agent')->name('agent.')->group(function () {

    Route::get('/',[AgentController::class,'AgentLogin']);
    
    Route::middleware(['guest:AgentLogin'])->group(function () {
        Route::get('/login',[AgentController::class,'AgentLogin'])->name('login');
        Route::post('/dologin',[AgentController::class,'AgentLogedIn'])->name('dologin');
    });

    Route::middleware(['auth:AgentLogin'])->group(function () {
        Route::get('/dashboard',[AgentController::class,'dashboard'])->name('dashboard');
        Route::post('/dashboard/search/{agentid}',[AgentController::class,'dashSearch'])->name('dashSearch');
        Route::get('/generateReport',[AgentController::class,'generateReport'])->name('generateReport');
        Route::post('/generateReport',[AgentController::class,'GetReport'])->name('GetReport');

        Route::get('/dashboard/{id}/{agentId}',[AgentController::class,'orderDetails'])->name('orderDetails');
        Route::post('/dashboard/{id}/{agentId}',[AgentController::class,'UpdateProductStatus'])->name('UpdateProductStatus');  

        Route::get('/updateStatus',[AgentController::class,'updateStatus'])->name('updateStatus');
        Route::get('/logout', [AgentController::class, 'logout'])->name('logout');
    });
});

Route::get('/all-agents',[RegisterController::class,'allAgents'])->name('all-agents');
Route::get('/edit/{id}',[RegisterController::class,'register'])->name('edit');
Route::get('/register',[RegisterController::class,'register'])->name('register');
Route::post('/register',[RegisterController::class,'doRegister'])->name('doregister');




